{% extends "accounts/base_site.html" %}
{% load i18n %}

{% block title %}{% if subtitle %}{{ subtitle }} | {% endif %}{{ title }} |
  {{ site_title|default:_('Logged out') }}{% endblock %}

{% block nav-global %}{% endblock %}

{% block breadcrumbs %}
  <div class="breadcrumbs"><a href="{% url 'accounts:login' %}">{% translate 'Home' %}</a></div>{% endblock %}

{% block nav-sidebar %}{% endblock %}

{% block content %}

  <p>{% translate "Thanks for spending some quality time with the web site today." %}</p>

  <p><a href="{% url 'accounts:login' %}" id="thuantest">{% translate 'Log in again' %}</a></p>

{% endblock %}
